@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9448 2015-10-05 06:21:52Z Eric $
+# $Id: urls.py 10057 2017-06-18 15:16:01Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-10-05 14:21:52 +0800 (Mon, 05 Oct 2015) $
-# $Revision: 9448 $
+# $Author: David $ (last)
+# $Date: 2017-06-18 23:16:01 +0800 (Sun, 18 Jun 2017) $
+# $Revision: 10057 $
 
 from django.conf.urls import include, url
 from views import *
@@ -28,5 +28,5 @@ urlpatterns = [
     url(r"^password/reset/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$", PasswordResetTokenView.as_view(), name="account_password_reset_token"),
     url(r"^settings/$", SettingsView.as_view(), name="account_settings"),
     url(r"^delete/$", DeleteView.as_view(), name="account_delete"),
-    url('', include('social.apps.django_app.urls', namespace='social')),
+    url('', include('social_django.urls', namespace='social')),
 ]
